@@ -9,11 +9,11 @@ json <-postRequest("Report.GetReportQueue")
 if(json$status == 200) {
 result <- content(json)
 } else {
-  return(jsonResponseError(json$status))
+  stop(jsonResponseError(json$status))
 }
 
 if(length(result) ==0) {
-  return(print("There are no reports in the Report Queue"))
+  warning("There are no reports in the Report Queue")
 } else {
 return(result)
 }
